Enum iroh_bytes::provider::GetProgress
source · pub enum GetProgress {
Connected,
Found {
id: u64,
hash: Hash,
size: u64,
},
FoundCollection {
hash: Hash,
num_blobs: Option<u64>,
total_blobs_size: Option<u64>,
},
Progress {
id: u64,
offset: u64,
},
Done {
id: u64,
},
NetworkDone {
bytes_written: u64,
bytes_read: u64,
elapsed: Duration,
},
Export {
id: u64,
hash: Hash,
size: u64,
target: String,
},
ExportProgress {
id: u64,
offset: u64,
},
Abort(RpcError),
AllDone,
}Expand description
Progress updates for the get operation.
Variants
Connected
A new connection was established.
Found
Fields
An item was found with hash hash, from now on referred to via id.
FoundCollection
Fields
An item was found with hash hash, from now on referred to via id.
Progress
We got progress ingesting item id.
Done
We are done with id, and the hash is hash.
NetworkDone
Fields
We are done with the network part - all data is local.
Export
Fields
The download part is done for this id, we are now exporting the data to the specified out path.
ExportProgress
Fields
We have made progress exporting the data.
This is only sent for large blobs.
Abort(RpcError)
We got an error and need to abort.
AllDone
We are done with the whole operation.