Utility functions and types.
Modules
Structs
- Sparse
MemFile - A file that is sparse in memory
- Tag
- A tag
- TagSet
- A set of merged
SetTagOptions for a blob. - TempTag
- A hash and format pair that is protected from garbage collection.
Enums
- MemOr
File - This is a general purpose Either, just like Result, except that the two cases are Mem for something that is in memory, and File for something that is somewhere external and only available via io.
- SetTag
Option - Option for commands that allow setting a tag
Traits
- Liveness
Tracker - A trait for things that can track liveness of blobs and collections.
Functions
- total_
bytes - Get the number of bytes given a set of chunk ranges and the total size.